@@ -16,6 +16,10 @@
 #' @param right_closed A single logical value representing whether to treat
 #'   right ends of intervals as their parts.
 #' @param f A pdqr-function.
+#' @param region2 A data frame representing region.
+#' @param method Method for computing distance between regions in
+#'   `region_distance()`. Should be one of "Jaccard" or methods of
+#'   [summ_distance()].
 #' @param col Single color of rectangles to be used. Should be appropriate for
 #'   `col` argument of [col2rgb()][grDevices::col2rgb()].
 #' @param alpha Single number representing factor modifying the opacity alpha;
@@ -52,6 +56,18 @@
 #' `region_width()` computes total width of a region, i.e. sum of differences
 #' between "right" and "left" columns.
 #'
+#' `region_distance()` computes distance between a pair of regions. As in
+#' [summ_distance()], it is a single non-negative number representing how much
+#' two regions differ from one another (bigger values indicate bigger
+#' difference). Argument `method` represents method of computing distance.
+#' Method "Jaccard" computes Jaccard distance: one minus ratio of intersection
+#' width and union width. Other methods come from `summ_distance()` and
+#' represent distance between regions as probability distributions:
+#' - If total width of region is zero (i.e. it consists only from points),
+#' distribution is a uniform discrete one based on points from region.
+#' - If total width is positive, then distribution is a uniform continuous one
+#' based on intervals with positive width.
+#'
 #' `region_draw()` draws (on current plot) intervals stored in `region` as
 #' colored rectangles vertically starting from zero and ending in the top of the
 #' plot (technically, at "y" value of `2e8`).
@@ -81,7 +97,7 @@
 #' d_binom <- as_d(dbinom, size = 10, prob = 0.7)
 #' hdr_dis <- summ_hdr(d_binom, level = 0.6)
 #' region_is_in(hdr_dis, 0:10)
-#'   # This should be not less than 0.6
+#' ## This should be not less than 0.6
 #' region_prob(hdr_dis, d_binom)
 #' region_height(hdr_dis, d_binom)
 #' region_width(hdr_dis)
@@ -90,38 +106,43 @@
 #' d_norm <- as_d(dnorm)
 #' hdr_con <- summ_hdr(d_norm, level = 0.95)
 #' region_is_in(hdr_con, c(-Inf, -2, 0, 2, Inf))
-#'   # This should be approximately equal to 0.95
+#' ## This should be approximately equal to 0.95
 #' region_prob(hdr_con, d_norm)
-#'   # This should be equal to `d_norm(hdr_con[["left"]][1])`
+#' ## This should be equal to `d_norm(hdr_con[["left"]][1])`
 #' region_height(hdr_con, d_norm)
 #' region_width(hdr_con)
 #'
 #' # Usage of `*_closed` options
 #' region <- data.frame(left = 1, right = 3)
-#'   # Closed intervals
+#' ## Closed intervals
 #' region_is_in(region, 1:3)
-#'   # Open from left, closed from right
+#' ## Open from left, closed from right
 #' region_is_in(region, 1:3, left_closed = FALSE)
-#'   # Closed from left, open from right
+#' ## Closed from left, open from right
 #' region_is_in(region, 1:3, right_closed = FALSE)
-#'   # Open intervals
+#' ## Open intervals
 #' region_is_in(region, 1:3, left_closed = FALSE, right_closed = FALSE)
 #'
 #' # Handling of intervals with zero width
 #' region <- data.frame(left = 1, right = 1)
-#'   # If at least one of `*_closed` options is `TRUE`, 1 will be considered as
-#'   # "in a region"
+#' ## If at least one of `*_closed` options is `TRUE`, 1 will be considered as
+#' ## "in a region"
 #' region_is_in(region, 1)
 #' region_is_in(region, 1, left_closed = FALSE)
 #' region_is_in(region, 1, right_closed = FALSE)
-#'   # Only this will return `FALSE`
+#' ## Only this will return `FALSE`
 #' region_is_in(region, 1, left_closed = FALSE, right_closed = FALSE)
 #'
+#' # Distance between regions
+#' region1 <- data.frame(left = c(0, 2), right = c(1, 2))
+#' region2 <- data.frame(left = 0.5, right = 1.5)
+#' region_distance(region1, region2, method = "Jaccard")
+#' region_distance(region1, region2, method = "KS")
+#'
 #' # Drawing
 #' d_mix <- form_mix(list(as_d(dnorm), as_d(dnorm, mean = 5)))
 #' plot(d_mix)
 #' region_draw(summ_hdr(d_mix, 0.95))
-#'
 #' @name region
 NULL
 
@@ -134,6 +155,9 @@ region_is_in <- function(region, x, left_closed = TRUE, right_closed = TRUE) {
   assert_type(left_closed, is_truefalse, "`TRUE` or `FALSE`")
   assert_type(right_closed, is_truefalse, "`TRUE` or `FALSE`")
 
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
   # Using `findInterval()` is safe because `region` should represent ordered
   # distinct intervals
   left_ind <- findInterval(x, region[["left"]], left.open = !left_closed)
@@ -160,6 +184,9 @@ region_prob <- function(region, f, left_closed = TRUE, right_closed = TRUE) {
   assert_type(left_closed, is_truefalse, "`TRUE` or `FALSE`")
   assert_type(right_closed, is_truefalse, "`TRUE` or `FALSE`")
 
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
   if (meta_type(f) == "discrete") {
     x_tbl <- meta_x_tbl(f)
 
@@ -186,6 +213,9 @@ region_height <- function(region, f, left_closed = TRUE, right_closed = TRUE) {
   assert_type(left_closed, is_truefalse, "`TRUE` or `FALSE`")
   assert_type(right_closed, is_truefalse, "`TRUE` or `FALSE`")
 
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
   x <- meta_x_tbl(f)[["x"]]
   x_is_in_region <- region_is_in(
     region, x, left_closed = left_closed, right_closed = right_closed
@@ -216,6 +246,86 @@ region_width <- function(region) {
   sum(region[["right"]] - region[["left"]])
 }
 
+#' @rdname region
+#' @export
+region_distance <- function(region, region2, method = "Jaccard") {
+  assert_region(region)
+  assert_region(region2)
+  assert_method(method, c("Jaccard", methods_distance))
+
+  # Speed optimization (skips possibly expensive assertions)
+  disable_asserting_locally()
+
+  switch(
+    method,
+    Jaccard = region_distance_jaccard(region, region2),
+    # Method "avgdist" is implemented separately for accuracy and performance
+    avgdist = region_distance_avgdist(region, region2),
+    # Method "entropy" is implemented separately to throw informative error
+    entropy = {
+      region_pdqr <- region_as_pdqr(region)
+      region2_pdqr <- region_as_pdqr(region2)
+      if (meta_type(region_pdqr) != meta_type(region2_pdqr)) {
+        stop_collapse(
+          'For method "entropy", regions should represent distribution of the ',
+          "same type (either both have zero width or both have positive width)."
+        )
+      }
+
+      summ_distance(region_pdqr, region2_pdqr, method)
+    },
+    summ_distance(region_as_pdqr(region), region_as_pdqr(region2), method)
+  )
+}
+
+region_distance_jaccard <- function(region, region2) {
+  # Compute grid of all possible breaks from either `region` or `region2`
+  breaks <- sort(unique(c(unlist(region), unlist(region2))))
+  names(breaks) <- NULL
+  l <- breaks[-length(breaks)]
+  r <- breaks[-1]
+  mids <- (l + r) / 2
+  lens <- r - l
+
+  # Determine if intervals of grid are in input regions
+  interval_is_in_1 <- region_is_in(region, mids)
+  interval_is_in_2 <- region_is_in(region2, mids)
+
+  # Determine if intervals of grid are in intersection and union of regions
+  interval_is_in_intercept <- interval_is_in_1 & interval_is_in_2
+  interval_is_in_union     <- interval_is_in_1 | interval_is_in_2
+
+  # Compute result based on fact that length of intersection/union is equal to
+  # sum of lengths of grid intervals that are their part
+  1 - sum(lens[interval_is_in_intercept]) / sum(lens[interval_is_in_union])
+}
+
+region_distance_avgdist <- function(region, region2) {
+  left <- region[["left"]]
+  right <- region[["right"]]
+  left2 <- region2[["left"]]
+  right2 <- region2[["right"]]
+
+  # For every interval in `region` compute its distance to `region2`
+  interval_region2 <- vapply(seq_len(nrow(region)), function(i) {
+    # For every interval in `region2` compute its distance to current interval
+    # in `region`
+    interval_interval2 <- vapply(seq_len(nrow(region2)), function(j) {
+      mean_unif_dist(left[i], right[i], left2[j], right2[j])
+    }, numeric(1))
+
+    # Distance from interval to `region2` is a weighted sum of
+    # "interval-interval" distances. This aligns with treating regions as
+    # uniform distributions on them. **Note** that it means zero length
+    # intervals are not used if there is at least one interval with positive
+    # length.
+    sum(interval_interval2 * to_weights(right2 - left2))
+  }, numeric(1))
+
+  # "region-region" distance is a weighted sum of "interval-region" distances
+  sum(interval_region2 * to_weights(right - left))
+}
+
 #' @rdname region
 #' @export
 region_draw <- function(region, col = "blue", alpha = 0.2) {
@@ -227,27 +337,29 @@ region_draw <- function(region, col = "blue", alpha = 0.2) {
   # problems with what seemed like overflow: when setting too big `ytop`
   # rectangles were drawn downward and not upward.
   n <- nrow(region)
-  x <- numeric(5*n)
-  y <- numeric(5*n)
-  rect_id_start <- 5*seq_len(n) - 4
+  x <- numeric(5 * n)
+  y <- numeric(5 * n)
+  rect_id_start <- 5 * seq_len(n) - 4
 
   x[rect_id_start] <- region[["left"]]
-  x[rect_id_start+1] <- region[["left"]]
-  x[rect_id_start+2] <- region[["right"]]
-  x[rect_id_start+3] <- region[["right"]]
-  x[rect_id_start+4] <- NA
+  x[rect_id_start + 1] <- region[["left"]]
+  x[rect_id_start + 2] <- region[["right"]]
+  x[rect_id_start + 3] <- region[["right"]]
+  x[rect_id_start + 4] <- NA
 
   y[rect_id_start] <- 0
-  y[rect_id_start+1] <- 2e8
-  y[rect_id_start+2] <- 2e8
-  y[rect_id_start+3] <- 0
-  y[rect_id_start+4] <- NA
+  y[rect_id_start + 1] <- 2e8
+  y[rect_id_start + 2] <- 2e8
+  y[rect_id_start + 3] <- 0
+  y[rect_id_start + 4] <- NA
 
   graphics::polygon(
     x, y, border = NA, col = grDevices::adjustcolor(col, alpha.f = alpha)
   )
 }
 
+
+# Helpers -----------------------------------------------------------------
 region_new <- function(left, right) {
   output_region <- data.frame(left = left, right = right)
   assert_region(output_region)
@@ -270,14 +382,18 @@ assert_region <- function(df) {
   if (!is.data.frame(df)) {
     stop_collapse(start_msg, "It should be a data frame.")
   }
-  if (!(("left" %in% names(df)) && is.numeric(df[["left"]]) &&
-        all(is.finite(df[["left"]])))) {
+  if (!(
+    ("left" %in% names(df)) && is.numeric(df[["left"]]) &&
+      all(is.finite(df[["left"]]))
+  )) {
     stop_collapse(
       start_msg, 'It should have numeric column "left" with finite values.'
     )
   }
-  if (!(("right" %in% names(df)) && is.numeric(df[["right"]]) &&
-        all(is.finite(df[["right"]])))) {
+  if (!(
+    ("right" %in% names(df)) && is.numeric(df[["right"]]) &&
+      all(is.finite(df[["right"]]))
+  )) {
     stop_collapse(
       start_msg, 'It should have numeric column "right" with finite values.'
     )
@@ -291,8 +407,8 @@ assert_region <- function(df) {
   if (!is_region_ordered(df)) {
     stop_collapse(
       start_msg, 'Columns "left" and "right" should represent ordered set of ',
-      'distinct intervals: left[1] <= right[1] <= left[2] <= rihgt[2] <= ..., ',
-      'and there should not be duplicated intervals.'
+      "distinct intervals: left[1] <= right[1] <= left[2] <= rihgt[2] <= ..., ",
+      "and there should not be duplicated intervals."
     )
   }
 
@@ -305,7 +421,41 @@ is_region_ordered <- function(df) {
   comb <- alternate(df[["left"]], df[["right"]])
 
   # Order condition
-  all(order(comb) == seq_len(2*nrow(df))) &&
+  all(order(comb) == seq_len(2 * nrow(df))) &&
     # Uniqueness condition
     !any(duplicated(df[, c("left", "right")]))
 }
+
+# Region is transformed into a random variable based on the following algorithm:
+# - If all intervals have "zero" lengths (based on 1e-10 tolerance), output is a
+#   uniform discrete discrete distribution over their values (left edges).
+# - If there is at least one interval with positive length, output is a uniform
+#   continuous distribution over the region. This means that intervals with zero
+#   length don't affect output, because their probability with respect to output
+#   random variable is zero.
+region_as_pdqr <- function(region) {
+  interval_is_point <- is_zero(region[["right"]] - region[["left"]])
+
+  if (all(interval_is_point)) {
+    res <- new_d(region[["left"]], "discrete")
+  } else {
+    region_con <- region[!interval_is_point, , drop = FALSE]
+
+    interval_width <- region_con[["right"]] - region_con[["left"]]
+    mix_weights <- to_weights(interval_width)
+
+    f_list <- lapply(seq_len(nrow(region_con)), function(i) {
+      new_d(
+        x = data.frame(
+          x = c(region_con[["left"]][i], region_con[["right"]][i]),
+          y = c(1, 1)
+        ),
+        type = "continuous"
+      )
+    })
+
+    res <- form_mix(f_list, weights = mix_weights)
+  }
+
+  res
+}
