@@ -3,7 +3,7 @@ context("test-form_tails")
 
 # Custom expectations -----------------------------------------------------
 expect_self_x_tbl <- function(pdqr_f) {
-  for (method in c("trim", "winsor")) {
+  for (method in methods_tails) {
     for (dir in c("both", "left", "right")) {
       expect_equal_x_tbl(form_tails(pdqr_f, 0, method, dir), pdqr_f)
     }
@@ -13,7 +13,7 @@ expect_self_x_tbl <- function(pdqr_f) {
 expect_dirac <- function(pdqr_f, x_vec) {
   max_levels <- c("both" = 0.5, "left" = 1, "right" = 1)
 
-  for (method in c("trim", "winsor")) {
+  for (method in methods_tails) {
     for (dir in c("both", "left", "right")) {
       expect_equal_x_tbl(
         form_tails(pdqr_f, max_levels[dir], method, dir),
@@ -24,7 +24,7 @@ expect_dirac <- function(pdqr_f, x_vec) {
 }
 
 expect_error_negative_level <- function(pdqr_f) {
-  for (method in c("trim", "winsor")) {
+  for (method in methods_tails) {
     for (dir in c("both", "left", "right")) {
       expect_error(
         form_tails(pdqr_f, -0.1, method = method, direction = dir),
@@ -156,10 +156,10 @@ test_that("form_tails works with `method='winsor'` and 'continuous' type", {
   expect_ref_x_tbl(
     form_tails(cur_con, 0.1, "winsor", "both"),
     data.frame(
-      x = c(  0.1, 0.1+1e-8, 0.9-1e-8,   0.9),
+      x = c(0.1,     0.1 + 1e-8, 0.9 - 1e-8, 0.9),
       # Here `2e7+1` is used instead of `2e7` due to (seems like) numerical
       # representation issues
-      y = c(2e7+1,        1,        1, 2e7+1)
+      y = c(2e7 + 1, 1,          1,          2e7 + 1)
     )
   )
 
@@ -167,10 +167,10 @@ test_that("form_tails works with `method='winsor'` and 'continuous' type", {
   expect_ref_x_tbl(
     form_tails(cur_con, 0.1, "winsor", "left"),
     data.frame(
-      x = c(  0.1, 0.1+1e-8, 1),
+      x = c(0.1,     0.1 + 1e-8, 1),
       # Here `2e7+1` is used instead of `2e7` due to (seems like) numerical
       # representation issues
-      y = c(2e7+1,        1, 1)
+      y = c(2e7 + 1, 1,          1)
     )
   )
 
@@ -178,10 +178,10 @@ test_that("form_tails works with `method='winsor'` and 'continuous' type", {
   expect_ref_x_tbl(
     form_tails(cur_con, 0.1, "winsor", "right"),
     data.frame(
-      x = c(0, 0.9-1e-8,   0.9),
+      x = c(0, 0.9 - 1e-8, 0.9),
       # Here `2e7+1` is used instead of `2e7` due to (seems like) numerical
       # representation issues
-      y = c(1,        1, 2e7+1)
+      y = c(1, 1,          2e7 + 1)
     )
   )
 })
